define(
//begin v1.x content
({
	insertTableTitle: "Vstavi tabelo",
	modifyTableTitle: "Spremeni tabelo",
	rows: "Vrstice:",
	columns: "Stolpci:",
	align: "Poravnaj:",
	cellPadding: "Polnjenje celic:",
	cellSpacing: "Razmik med celicami:",
	tableWidth: "Širina tabele:",
	backgroundColor: "Barva ozadja:",
	borderColor: "Barva obrobe:",
	borderThickness: "Debelina obrobe",
	percent: "odstotkov",
	pixels: "pikslov",
	"default": "privzeto",
	left: "levo",
	center: "na sredini",
	right: "desno",
	buttonSet: "Nastavi", // translated elsewhere?
	buttonInsert: "Vstavi",
	buttonCancel: "Prekliči",

	selectTableLabel: "Izberi tabelo",
	insertTableRowBeforeLabel: "Dodaj vrstico pred",
	insertTableRowAfterLabel: "Dodaj vrstico za",
	insertTableColumnBeforeLabel: "Dodaj stolpec pred",
	insertTableColumnAfterLabel: "Dodaj stolpec za",
	deleteTableRowLabel: "Izbriši vrstico",
	deleteTableColumnLabel: "Izbriši stolpec"
})
	

//end v1.x content
);
